@@ -89,6 +89,7 @@ from .kernel import MyKernel
 from .kernel import start_qtconsole
 from .utils import b64decode
 from .utils import capture
+from .utils import combo_box_from_enum
 from .utils import create_code_snippet
 from .utils import create_code_snippet_renderable
 from .utils import is_renderable
@@ -96,6 +97,7 @@ from .utils import select_directory
 from .utils import select_file
 from .utils import stringify_args
 from .utils import stringify_kwargs
+from .utypes import Callback
 from .utypes import TypeObject
 from .utypes import UQWidget
 
@@ -722,12 +724,6 @@ class DynamicButton(QWidget):
         return f"DynamicButton(\"{self.label}\", {self.function})"
 
 
-def combo_box_from_enum(enumeration: Enum):
-    cb = QComboBox()
-    cb.addItems([x.name for x in enumeration])
-    return cb
-
-
 class ArgumentsPanel(QScrollArea):
     def __init__(self, button: DynamicButton, ui_args: Dict[str, Argument]):
         super().__init__()
@@ -753,6 +749,7 @@ class ArgumentsPanel(QScrollArea):
                 }
             """)
         )
+        widget.setContentsMargins(0, 5, 0, 0)
 
         main_layout = QHBoxLayout()
 
@@ -773,10 +770,12 @@ class ArgumentsPanel(QScrollArea):
             if arg.annotation is bool:
                 input_field = QCheckBox("")
                 input_field.setCheckState(Qt.Checked if arg.default else Qt.Unchecked)
-            elif isinstance(arg.annotation, TypeObject):
+            elif isinstance(arg.annotation, (TypeObject, Callback)):
                 input_field: QWidget = arg.annotation.get_widget()
             elif inspect.isclass(arg.annotation) and issubclass(arg.annotation, Enum):
-                input_field = combo_box_from_enum(arg.annotation)
+                input_field: QComboBox = combo_box_from_enum(arg.annotation)
+                if arg.default is not None:
+                    input_field.setCurrentText(arg.default.name)
             else:
                 input_field = QLineEdit()
                 input_field.setObjectName(name)
@@ -849,10 +848,12 @@ class ArgumentsPanel(QScrollArea):
         button_group.addButton(self.script_rb, RUNNABLE_SCRIPT)
 
         self.run_button = QPushButton("run")
+        self.close_button = QPushButton("close")
         hbox.addWidget(self.kernel_rb)
         hbox.addWidget(self.app_rb)
         hbox.addWidget(self.script_rb)
         hbox.addStretch()
+        hbox.addWidget(self.close_button)
         hbox.addWidget(self.run_button)
 
         vbox.addStretch()
@@ -1119,6 +1120,16 @@ class View(QMainWindow):
         qtconsole_button.triggered.connect(self.start_qt_console)
         qtconsole_button.setCheckable(False)
         self._toolbar.addAction(qtconsole_button)
+
+        # Add a button to the toolbar to interrupt the kernel
+
+        interrupt_button = QAction(QIcon(str(HERE / "icons/traffic-light-red.svg")), "Interrupt the Jupyter Kernel", self)
+        interrupt_button.setStatusTip("Interrupt the Jupyter Kernel")
+        interrupt_button.triggered.connect(self.interrupt_kernel)
+        interrupt_button.setCheckable(False)
+        self._toolbar.addAction(interrupt_button)
+
+
         self.kernel_panel = KernelPanel(self.kernel_name)
         self._toolbar.addWidget(self.kernel_panel)
 
@@ -1192,6 +1203,9 @@ class View(QMainWindow):
                 )
             )
 
+    def interrupt_kernel(self):
+        self._kernel.interrupt_kernel()
+
     def start_qt_console(self):
         if self._qt_console is not None and self._qt_console.is_running:
             dialog = QMessageBox.information(self, "Qt Console", "There is already a Qt Console running.")
@@ -1274,6 +1288,7 @@ class View(QMainWindow):
                 args_panel.function, args_panel.args, args_panel.kwargs, args_panel.runnable
             )
         )
+        args_panel.close_button.clicked.connect(self.close_args_panel)
         args_panel.setSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.Minimum)
 
         if self._args_panel is None:
@@ -1294,6 +1309,12 @@ class View(QMainWindow):
 
         self._buttons_panel.ensureWidgetVisible(button)
 
+    def close_args_panel(self):
+        self._args_panel.hide()
+        self._args_panel = None
+        if self.previous_selected_button is not None:
+            self.previous_selected_button.deselect()
+
     @pyqtSlot(object)
     def function_output(self, data: object):
         self._console_panel.append(data if is_renderable(data) else str(data))
